@@ -1,8 +1,6 @@
 from pathlib import Path
 from typing import Any, Dict, List, Optional, Text
 
-from rasa.shared.nlu.training_data.training_data import TrainingData
-
 from neuralspace.constants import (
     ELEMENTS,
     ENTITIES,
@@ -19,6 +17,7 @@ from neuralspace.constants import (
 )
 from neuralspace.datamodels import DatasetType
 from neuralspace.nlu.converters.base import DataConverter
+from neuralspace.nlu.converters.rasa.training_data.training_data import TrainingData
 from neuralspace.nlu.utils import (
     auto_tag_lookup,
     auto_tag_pretrained_entities,
@@ -138,11 +137,19 @@ class RasaConverter(DataConverter):
     def number_of_unique_intent(self):
         return len(set([example[INTENT] for example in self.nlu_data]))
 
-    def post_process(self, dataset_type, output_directory):
+    def post_process(
+        self,
+        dataset_type,
+        output_directory,
+        authtoken: Text = None,
+        dataset_id: Text = None,
+    ):
         if self.entity_mapping:
             self.nlu_data = map_entities(self.nlu_data, self.entity_mapping)
         if self.auto_tag_entities:
-            self.nlu_data = auto_tag_pretrained_entities(self.nlu_data, self.language)
+            self.nlu_data = auto_tag_pretrained_entities(
+                self.nlu_data, self.language, authtoken=authtoken
+            )
             self.nlu_data = auto_tag_lookup(self.nlu_data, self.lookup_data)
             self.nlu_data = auto_tag_regex(self.nlu_data, self.regex_data)
         self.number_of_nlu_examples_before_duplicate_check = self.count(self.nlu_data)
@@ -164,12 +171,20 @@ class RasaConverter(DataConverter):
             lookup_data=self.lookup_data,
             synonym_data=self.synonym_data,
             regex_data=self.regex_data,
+            dataset_id=dataset_id,
         )
 
     def convert(
-        self, input_path: List[Path], output_directory: Path, dataset_type: DatasetType
+        self,
+        input_path: List[Path],
+        output_directory: Path,
+        dataset_type: DatasetType,
+        authtoken: Text = None,
+        dataset_id: Text = None,
     ):
-        from rasa.shared.importers.utils import training_data_from_paths
+        from neuralspace.nlu.converters.rasa.shared.importers.utils import (
+            training_data_from_paths,
+        )
 
         for single_path in input_path:
             data: TrainingData = training_data_from_paths(
@@ -180,7 +195,12 @@ class RasaConverter(DataConverter):
             self.regex_data += self.__regex_converter(data.regex_features)
             self.synonym_data += self.__synonym_converter(data.entity_synonyms)
 
-        self.post_process(dataset_type=dataset_type, output_directory=output_directory)
+        self.post_process(
+            dataset_type=dataset_type,
+            output_directory=output_directory,
+            authtoken=authtoken,
+            dataset_id=dataset_id,
+        )
 
     def component_convert(self, training_data: TrainingData, dataset_type: DatasetType):
         self.nlu_data += self.__nlu_data_converter(training_data)
